@@ -860,6 +860,7 @@ var PMA_consoleMessages = {
             if(confirm(PMA_messages.strConsoleDeleteBookmarkConfirm + '\n' + $message.find('.bookmark_label').text())) {
                 $.post('import.php',
                     {token: PMA_commonParams.get('token'),
+                    server: PMA_commonParams.get('server'),
                     action_bookmark: 2,
                     ajax_request: true,
                     id_bookmark: $message.attr('bookmarkid')},
@@ -963,8 +964,11 @@ var PMA_consoleBookmarks = {
         }
     },
     refresh: function () {
-        $.get('import.php?console_bookmark_refresh=refresh&token=' + PMA_commonParams.get('token'),
-            {'ajax_request': true},
+        $.get('import.php',
+            {ajax_request: true,
+            token: PMA_commonParams.get('token'),
+            server: PMA_commonParams.get('server'),
+            console_bookmark_refresh: 'refresh'},
             function(data) {
                 if(data.console_message_bookmark) {
                     $('#pma_bookmarks .content.bookmark').html(data.console_message_bookmark);
@@ -1001,6 +1005,7 @@ var PMA_consoleBookmarks = {
                 ajax_request: true,
                 console_bookmark_add: 'true',
                 label: $('#pma_bookmarks .card.add [name=label]').val(),
+                server: PMA_commonParams.get('server'),
                 db: $('#pma_bookmarks .card.add [name=targetdb]').val(),
                 bookmark_query: PMA_consoleInput.getText('bookmark'),
                 shared: $('#pma_bookmarks .card.add [name=shared]').prop('checked')},
