@@ -969,12 +969,6 @@ h3#serverstatusqueries span {
     display:inline;
 }
 
-img.sortableIcon {
-    float:right;
-    background-repeat:no-repeat;
-    margin:0;
-}
-
 .buttonlinks {
     float: <?php echo $right; ?>;
     white-space: nowrap;
